@@ -75,7 +75,12 @@ set_utf8 = function(x) {
 #' lead to spurious errors that accompanying \code{*.shp} are missing.
 #'
 #' In case of problems reading shapefiles from USB drives on OSX, please see
-#' \url{https://github.com/r-spatial/sf/issues/252}.
+#' \url{https://github.com/r-spatial/sf/issues/252}. Reading shapefiles (or other
+#' data sources) directly from zip files can be done by prepending the path 
+#' with \code{/vsizip/}. This is part of the GDAL Virtual File Systems interface
+#' that also supports .gz, curl, and other operations, including chaining; see
+#' \url{https://gdal.org/user/virtual_file_systems.html} for a complete
+#' description and examples.
 #'
 #' For \code{query} with a character \code{dsn} the query text is handed to
 #' 'ExecuteSQL' on the GDAL/OGR data set and will result in the creation of a
@@ -305,7 +310,7 @@ abbreviate_shapefile_names = function(x) {
 	if (length(wh. <- grep("\\.", fld_names) > 0))
 		fld_names[wh.] <- gsub("\\.", "_", fld_names[wh.])
 
-	if (length(fld_names) != length(unique(fld_names)))
+	if (anyDuplicated(fld_names))
 		stop("Non-unique field names") # nocov
 
 	names(x) = fld_names
