@@ -110,16 +110,16 @@ st_sample.sfc = function(x, size, ..., type = "random", exact = TRUE, warn_if_no
 		ret = if (progress) {
 				if (!requireNamespace("pbapply", quietly = TRUE))
 					stop("package pbapply required, please install it first")
-				pbapply::pblapply(1:length(x), function(i) st_sample(x[i], size[i], type = type, exact = exact, ...))
+				pbapply::pblapply(seq_along(x), function(i) st_sample(x[i], size[i], type = type, exact = exact, ...))
 			} else
-				lapply(1:length(x), function(i) st_sample(x[i], size[i], type = type, exact = exact, ...))
+				lapply(seq_along(x), function(i) st_sample(x[i], size[i], type = type, exact = exact, ...))
 		st_set_crs(do.call(c, ret), st_crs(x))
 	} else {
 		res = switch(max(st_dimension(x)) + 1,
 					 st_multipoints_sample(do.call(c, x), size = size, ..., type = type),
 					 st_ll_sample(st_cast(x, "LINESTRING"), size = size, ..., type = type),
 					 st_poly_sample(x, size = size, ..., type = type, by_polygon = by_polygon))
-		if (exact & type == "random" & all(st_geometry_type(res) == "POINT")) {
+		if (exact && type == "random" && all(st_geometry_type(res) == "POINT")) {
 			diff = size - length(res)
 			if (diff > 0) { # too few points
 				res_additional = st_sample_exact(x = x, size = diff, ..., 
