@@ -183,7 +183,7 @@ st_wrap_dateline.sfc = function(x, options = "WRAPDATELINE=YES", quiet = TRUE) {
 	else
 		stopifnot(st_is_longlat(x))
 	stopifnot(is.character(options))
-	stopifnot(is.logical(quiet) && length(quiet) == 1)
+	stopifnot(is.logical(quiet), length(quiet) == 1)
 	st_sfc(CPL_wrap_dateline(x, options, quiet), crs = st_crs(x))
 }
 
