@@ -6,7 +6,7 @@
 #
 hex_to_raw = function(y) {
 	stopifnot((nchar(y) %% 2) == 0)
-	if (substr(y, 1, 2) == "0x")
+	if (startsWith(y, "0x"))
 		y = substr(y, 3, nchar(y))
 	as.raw(as.numeric(paste0("0x", vapply(seq_len(nchar(y)/2),
 		function(x) substr(y, (x-1)*2+1, x*2), "")))) # SLOW, hence the Rcpp implementation
@@ -15,7 +15,7 @@ hex_to_raw = function(y) {
 skip0x = function(x) {
 	if (is.na(x))
 		"010700000000000000" # empty GeometryCollection, st_as_binary(st_geometrycollection())
-	else if (substr(x, 1, 2) == "0x")
+	else if (startsWith(x, "0x"))
 		substr(x, 3, nchar(x))
 	else
 		x
@@ -43,7 +43,7 @@ st_as_sfc.WKB = function(x, ..., EWKB = FALSE, spatialite = FALSE, pureR = FALSE
 			else
 				structure(CPL_hex_to_raw(vapply(x, skip0x, USE.NAMES = FALSE, "")), class = "WKB")
 	} else # direct call with raw:
-		stopifnot(inherits(x, "WKB") && all(vapply(x, is.raw, TRUE))) # WKB as raw
+		stopifnot(inherits(x, "WKB"), vapply(x, is.raw, TRUE)) # WKB as raw
 	if (any(lengths(x) == 0))
 		stop("cannot read WKB object from zero-length raw vector")
 	ret = if (pureR)
@@ -236,13 +236,17 @@ st_as_binary = function(x, ...) UseMethod("st_as_binary")
 #' @param pureR logical; use pure R solution, or C++?
 #' @param precision numeric; if zero, do not modify; to reduce precision: negative values convert to float (4-byte real); positive values convert to round(x*precision)/precision. See details.
 #' @param hex logical; return as (unclassed) hexadecimal encoded character vector?
+#' @param srid integer; override srid (can be used when the srid is unavailable locally).
 #' @details \code{st_as_binary} is called on sfc objects on their way to the GDAL or GEOS libraries, and hence does rounding (if requested) on the fly before e.g. computing spatial predicates like \link{st_intersects}. The examples show a round-trip of an \code{sfc} to and from binary.
 #'
 #' For the precision model used, see also \url{https://locationtech.github.io/jts/javadoc/org/locationtech/jts/geom/PrecisionModel.html}. There, it is written that: ``... to specify 3 decimal places of precision, use a scale factor of 1000. To specify -3 decimal places of precision (i.e. rounding to the nearest 1000), use a scale factor of 0.001.''. Note that ALL coordinates, so also Z or M values (if present) are affected.
 #' @export
 #' @examples
-#' x = st_sfc(st_point(c(1/3, 1/6)), precision = 1000)
-#' st_as_sfc(st_as_binary(x)) # rounds
+#' # examples of setting precision:
+#' st_point(c(1/3, 1/6)) %>% st_sfc(precision = 1000) %>% st_as_binary %>% st_as_sfc
+#' st_point(c(1/3, 1/6)) %>% st_sfc(precision =  100) %>% st_as_binary %>% st_as_sfc
+#' st_point(1e6 * c(1/3, 1/6)) %>% st_sfc(precision = 0.01) %>% st_as_binary %>% st_as_sfc
+#' st_point(1e6 * c(1/3, 1/6)) %>% st_sfc(precision = 0.001) %>% st_as_binary %>% st_as_sfc
 st_as_binary.sfc = function(x, ..., EWKB = FALSE, endian = .Platform$endian, pureR = FALSE,
 		precision = attr(x, "precision"), hex = FALSE) {
 	stopifnot(endian %in% c("big", "little"))
@@ -284,11 +288,11 @@ createType = function(x, endian, EWKB = FALSE) {
 #' @name st_as_binary
 #' @export
 st_as_binary.sfg = function(x, ..., endian = .Platform$endian, EWKB = FALSE, pureR = FALSE,
-		hex = FALSE) {
+		hex = FALSE, srid = 0) {
 # if pureR, it's done here, if not, it's done in st_as_binary.sfc
 	stopifnot(endian %in% c("big", "little"))
 	if (! pureR)
-		st_as_binary.sfc(st_sfc(x), endian == endian, EWKB = EWKB, pureR = pureR, hex = hex, ...)[[1]]
+		st_as_binary.sfc(st_sfc(x), endian == endian, EWKB = EWKB, pureR = pureR, hex = hex, srid = srid, ...)[[1]]
 	else {
 		rc <- rawConnection(raw(0), "r+")
 		on.exit(close(rc))
